==> hive-apache-3.1.2-5-sources.jar: org/apache/hadoop/hive/common/ndv/NumDistinctValueEstimator.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.hadoop.hive.common.ndv;

import io.prestosql.hive.$internal.org.slf4j.Logger;
import io.prestosql.hive.$internal.org.slf4j.LoggerFactory;
import org.apache.hadoop.hive.common.type.HiveDecimal;
import org.apache.hadoop.hive.ql.util.JavaDataModel;

public interface NumDistinctValueEstimator {

  Logger LOG = LoggerFactory.getLogger(NumDistinctValueEstimator.class.getName());

  void reset();

  byte[] serialize();
  
  NumDistinctValueEstimator deserialize(byte[] buf);

  void addToEstimator(long v);

  void addToEstimator(double d);

  void addToEstimator(String s);

  void addToEstimator(HiveDecimal decimal);

  void mergeEstimators(NumDistinctValueEstimator o);

  long estimateNumDistinctValues();

  int lengthFor(JavaDataModel model);

  boolean canMerge(NumDistinctValueEstimator o);

}

==> hive-apache-3.1.2-13-sources.jar: org/apache/hadoop/hive/common/ndv/NumDistinctValueEstimator.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.hadoop.hive.common.ndv;

import io.trino.hive.$internal.org.slf4j.Logger;
import io.trino.hive.$internal.org.slf4j.LoggerFactory;
import org.apache.hadoop.hive.common.type.HiveDecimal;
import org.apache.hadoop.hive.ql.util.JavaDataModel;

public interface NumDistinctValueEstimator {

  Logger LOG = LoggerFactory.getLogger(NumDistinctValueEstimator.class.getName());

  void reset();

  byte[] serialize();
  
  NumDistinctValueEstimator deserialize(byte[] buf);

  void addToEstimator(long v);

  void addToEstimator(double d);

  void addToEstimator(String s);

  void addToEstimator(HiveDecimal decimal);

  void mergeEstimators(NumDistinctValueEstimator o);

  long estimateNumDistinctValues();

  int lengthFor(JavaDataModel model);

  boolean canMerge(NumDistinctValueEstimator o);

}
